@@ -1,22 +1,31 @@
-/*
- * BibTeX Converter
- * Copyright (C) 2010-2024 by Thomas Dreibholz
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Contact: thomas.dreibholz@gmail.com
- */
+// ==========================================================================
+//                ____  _ _   _____   __  ______
+//                | __ )(_) |_|_   _|__\ \/ / ___|___  _ ____   __
+//                |  _ \| | '_ \| |/ _ \  / |   / _ \| '_ \ \ / /
+//                | |_) | | |_) | |  __//  \ |__| (_) | | | \ V /
+//                |____/|_|_.__/|_|\___/_/\_\____\___/|_| |_|\_/
+//
+//                          ---  BibTeX Converter  ---
+//                   https://www.nntb.no/~dreibh/bibtexconv/
+// ==========================================================================
+//
+// BibTeX Converter
+// Copyright (C) 2010-2025 by Thomas Dreibholz
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
+// Contact: thomas.dreibholz@gmail.com
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -1171,7 +1180,6 @@ std::string PublicationSet::applyTemplate(Node*                           public
       else {
          std::string character = "";
 
-#ifdef USE_UTF8
          if( ( (((unsigned char)printingTemplate[i]) & 0xE0) == 0xC0 ) &&
                (i + 1 < printingTemplateSize) ) {
             // Two-byte UTF-8 character
@@ -1195,14 +1203,11 @@ std::string PublicationSet::applyTemplate(Node*                           public
          }
          else if( (((unsigned char)printingTemplate[i]) & 0x80) == 0 ) {
             // Regular 1-byte character
-#endif
             character += printingTemplate[i];
-#ifdef USE_UTF8
          }
          else {
             // Invalid!
          }
-#endif
 
          // Add current character. We may *not* use XML style encoding here,
          // since the character may be itself part of XML tags!
